==> nextcloud-app-tasks-0.14.5-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/tasks/l10n/es_MX.js <==
OC.L10N.register(
    "tasks",
    {
    "Important" : "Importante",
    "Today" : "Hoy",
    "Week" : "Semana",
    "All" : "Todos",
    "Current" : "Actual",
    "Completed" : "Completado",
    "Tasks" : "Tareas",
    "The Tasks app for Nextcloud" : "Una aplicación de Tareas para Nextcloud",
    "Visibility of Smart Collections" : "Visibilidad de Colecciones Inteligentes",
    "Hidden" : "Oculto",
    "Visible" : "Visible",
    "Automatic" : "Automático",
    "Share with users or groups" : "Compartir con otros usuarios o grupos",
    "Can edit" : "Puede editar",
    "Edit" : "Editar",
    "Export" : "Exportar",
    "Delete" : "Borrar",
    "Unshare" : "Dejar de compartir",
    "Save" : "Guardar",
    "An empty name is not allowed." : "No se permite un nombre vacío.",
    "Name" : "Nombre",
    "Deleted" : "Eliminado",
    "Restore" : "Restaurar",
    "Delete permanently" : "Borrar permanentemente",
    "Empty trash bin" : "Vaciar la papelera de reciclaje",
    "Change sort order" : "Cambiar el criterio para ordenar",
    "Start date" : "Fecha de inicio",
    "Due date" : "Fecha de vencimiento",
    "Last modified" : "Última modificación",
    "Priority" : "Prioridad",
    "Alphabetically" : "Alfabéticamente",
    "Manually" : "Manualmente",
    "Task is completed" : "La tarea ha sido completada",
    "Cancel" : "Cancelar",
    "Close" : "Cerrar",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n Tarea Completada","%n Tareas Completadas","%n Tareas Completadas"],
    "Tomorrow" : "Mañana",
    "New List" : "Nueva Lista",
    "All day" : "Todo el día",
    "Details" : "Detalles",
    "Select tags" : "Selecciona las etiquetas",
    "Notes" : "Notas",
    "Reminders" : "Recordatorios",
    "Repeat" : "Repetir",
    "When shared show full event" : "Al compartir, mostrar el evento completo",
    "When shared show only busy" : "Al compartir, mostrar sólo como ocupado ",
    "When shared hide this event" : "Al compartir, ocultar este evento ",
    "Canceled" : "Cancelada",
    "Task not found!" : "¡Tarea no encontrada!",
    "Set start date" : "Establecer fecha de inicio",
    "Set due date" : "Establecer fecha de vencimiento",
    "An error occurred" : "Ha ocurrido un error"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-app-tasks-0.15.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/tasks/l10n/es_MX.js <==
OC.L10N.register(
    "tasks",
    {
    "Upcoming tasks" : "Próximas tareas",
    "Important" : "Importante",
    "Today" : "Hoy",
    "Week" : "Semana",
    "All" : "Todos",
    "Current" : "Actual",
    "Completed" : "Completado",
    "Tasks" : "Tareas",
    "The Tasks app for Nextcloud" : "Una aplicación de Tareas para Nextcloud",
    "Visibility of Smart Collections" : "Visibilidad de Colecciones Inteligentes",
    "Hidden" : "Oculto",
    "Visible" : "Visible",
    "Automatic" : "Automático",
    "Share with users or groups" : "Compartir con otros usuarios o grupos",
    "Can edit" : "Puede editar",
    "Edit" : "Editar",
    "Export" : "Exportar",
    "Delete" : "Borrar",
    "Unshare" : "Dejar de compartir",
    "An empty name is not allowed." : "No se permite un nombre vacío.",
    "Name" : "Nombre",
    "Deleted" : "Eliminado",
    "Restore" : "Restaurar",
    "Delete permanently" : "Borrar permanentemente",
    "Empty trash bin" : "Vaciar la papelera de reciclaje",
    "Change sort order" : "Cambiar el criterio para ordenar",
    "Start date" : "Fecha de inicio",
    "Due date" : "Fecha de vencimiento",
    "Last modified" : "Última modificación",
    "Priority" : "Prioridad",
    "Alphabetically" : "Alfabéticamente",
    "Manually" : "Manualmente",
    "Task is completed" : "La tarea ha sido completada",
    "Create a new task" : "Crear una tarea nueva",
    "Cancel" : "Cancelar",
    "Close" : "Cerrar",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n Tarea Completada","%n Tareas Completadas","%n Tareas Completadas"],
    "Tomorrow" : "Mañana",
    "All day" : "Todo el día",
    "Details" : "Detalles",
    "Select tags" : "Selecciona las etiquetas",
    "Notes" : "Notas",
    "Reminders" : "Recordatorios",
    "Repeat" : "Repetir",
    "When shared show full event" : "Al compartir, mostrar el evento completo",
    "When shared show only busy" : "Al compartir, mostrar sólo como ocupado ",
    "When shared hide this event" : "Al compartir, ocultar este evento ",
    "Canceled" : "Cancelada",
    "Task not found!" : "¡Tarea no encontrada!",
    "Set start date" : "Establecer fecha de inicio",
    "Set due date" : "Establecer fecha de vencimiento",
    "No upcoming tasks" : "No hay tareas próximas",
    "upcoming tasks" : "tareas próximas",
    "Mark as done" : "Marcar como hecho",
    "No due date assigned" : "Fecha de vencimiento sin especificar",
    "An error occurred" : "Ha ocurrido un error"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
